﻿using Microsoft.EntityFrameworkCore.Migrations;

#nullable disable

namespace Zoo.DAL.Migrations
{
    public partial class Initial : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "Sponsor",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Sponsor", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Zookeeper",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    BadgeId = table.Column<int>(type: "int", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Zookeeper", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Animal",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    DateOfBirth = table.Column<DateTime>(type: "datetime2", nullable: false),
                    Weight = table.Column<double>(type: "float", nullable: true),
                    ZookeeperId = table.Column<Guid>(type: "uniqueidentifier", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Animal", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Animal_Zookeeper_ZookeeperId",
                        column: x => x.ZookeeperId,
                        principalTable: "Zookeeper",
                        principalColumn: "Id");
                });

            migrationBuilder.CreateTable(
                name: "Sponsorship",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    MonthlyAmount = table.Column<decimal>(type: "decimal(10,2)", nullable: false),
                    IsActive = table.Column<bool>(type: "bit", nullable: false),
                    AnimalId = table.Column<Guid>(type: "uniqueidentifier", nullable: true),
                    SponsorId = table.Column<Guid>(type: "uniqueidentifier", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Sponsorship", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Sponsorship_Animal_AnimalId",
                        column: x => x.AnimalId,
                        principalTable: "Animal",
                        principalColumn: "Id");
                    table.ForeignKey(
                        name: "FK_Sponsorship_Sponsor_SponsorId",
                        column: x => x.SponsorId,
                        principalTable: "Sponsor",
                        principalColumn: "Id");
                });

            migrationBuilder.InsertData(
                table: "Sponsor",
                columns: new[] { "Id", "Name" },
                values: new object[] { new Guid("528a0446-cc83-4000-9da5-2172049e85bc"), "Milan Bezdíček" });

            migrationBuilder.InsertData(
                table: "Zookeeper",
                columns: new[] { "Id", "BadgeId", "Name" },
                values: new object[] { new Guid("91faceea-867d-4c23-9d36-1b8ea296acde"), 585, "Petr Pavlíček" });

            migrationBuilder.InsertData(
                table: "Zookeeper",
                columns: new[] { "Id", "BadgeId", "Name" },
                values: new object[] { new Guid("b62dc578-e29d-40e1-ad50-1bc9bfcd123d"), 10, "Pavel Petříček" });

            migrationBuilder.InsertData(
                table: "Animal",
                columns: new[] { "Id", "DateOfBirth", "Name", "Weight", "ZookeeperId" },
                values: new object[,]
                {
                    { new Guid("4707b640-7477-46bd-bf5b-4914c9d0df61"), new DateTime(2015, 5, 2, 0, 0, 0, 0, DateTimeKind.Unspecified), "Leo the Giraffe", 1320.0, new Guid("b62dc578-e29d-40e1-ad50-1bc9bfcd123d") },
                    { new Guid("ba4df96a-316a-4aa7-ba20-835a3937f79b"), new DateTime(2018, 10, 9, 0, 0, 0, 0, DateTimeKind.Unspecified), "Coco the Gorilla", 140.0, new Guid("91faceea-867d-4c23-9d36-1b8ea296acde") },
                    { new Guid("de665c7b-365b-42c5-ba43-9f566f82f9ad"), new DateTime(2019, 5, 25, 0, 0, 0, 0, DateTimeKind.Unspecified), "Melvin the Porcupine", 9.5, new Guid("91faceea-867d-4c23-9d36-1b8ea296acde") },
                    { new Guid("ea14e772-0fff-4f5d-844b-b9f5d398f8df"), new DateTime(2010, 12, 25, 0, 0, 0, 0, DateTimeKind.Unspecified), "Alan the Crocodile", 1050.0, new Guid("b62dc578-e29d-40e1-ad50-1bc9bfcd123d") }
                });

            migrationBuilder.InsertData(
                table: "Sponsorship",
                columns: new[] { "Id", "AnimalId", "IsActive", "MonthlyAmount", "SponsorId" },
                values: new object[] { new Guid("1af0bcbe-2360-4d9a-8237-835fcd9a14c9"), new Guid("4707b640-7477-46bd-bf5b-4914c9d0df61"), true, 10000m, new Guid("528a0446-cc83-4000-9da5-2172049e85bc") });

            migrationBuilder.InsertData(
                table: "Sponsorship",
                columns: new[] { "Id", "AnimalId", "IsActive", "MonthlyAmount", "SponsorId" },
                values: new object[] { new Guid("62d0a5ac-c45c-48f8-8880-a44bff144357"), new Guid("de665c7b-365b-42c5-ba43-9f566f82f9ad"), true, 25000m, new Guid("528a0446-cc83-4000-9da5-2172049e85bc") });

            migrationBuilder.CreateIndex(
                name: "IX_Animal_ZookeeperId",
                table: "Animal",
                column: "ZookeeperId");

            migrationBuilder.CreateIndex(
                name: "IX_Sponsorship_AnimalId",
                table: "Sponsorship",
                column: "AnimalId");

            migrationBuilder.CreateIndex(
                name: "IX_Sponsorship_SponsorId",
                table: "Sponsorship",
                column: "SponsorId");
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "Sponsorship");

            migrationBuilder.DropTable(
                name: "Animal");

            migrationBuilder.DropTable(
                name: "Sponsor");

            migrationBuilder.DropTable(
                name: "Zookeeper");
        }
    }
}
