﻿using Microsoft.EntityFrameworkCore;
using Zoo.DAL;
using Zoo.DAL.Models;

using var dbContext = new ZooDbContext();

// Reading data

var animals = await dbContext.Animal.ToListAsync();

var animalsCount = animals.Count();

Console.WriteLine($"Animal count: {animalsCount}");

var allAnimalNames = $"All animals: {string.Join(",", animals.Select(anim => $"{anim.Name}"))}";

Console.WriteLine(allAnimalNames);

// Insert animal

var zookeepers = await dbContext.Zookeeper.ToListAsync();
var firstZookeeper = zookeepers.First();

var newGuidToAdd = Guid.NewGuid();

var sharkOrderNo = new Random().NextInt64(1, 100);

var animalToAdd = new Animal()
{
    DateOfBirth = new DateTime(2021, 2, 2),
    Name = $"Peter the Shark [{sharkOrderNo}]",
    Weight = 860,
    ZookeeperId = firstZookeeper.Id,
    Id = newGuidToAdd
};

await dbContext.Animal.AddAsync(animalToAdd);

// Rename Leo the Giraffe

var leoTheGiraffe = await dbContext.Animal.SingleOrDefaultAsync(anim => anim.Name.Contains("Leo"));

var giraffeOrderNo = new Random().NextInt64(1,100);
leoTheGiraffe.Name = $"Leonard the Giraffe the [{giraffeOrderNo}]";

await dbContext.SaveChangesAsync();

// Read new data

var newAnimalList = await dbContext.Animal.ToListAsync();

var newAnimalNames = $"All animals: {string.Join(",", newAnimalList.Select(anim => $"{anim.Name}"))}";

Console.WriteLine($"New animal names:{Environment.NewLine}{newAnimalNames}");
